-- Import addon data
local _, addonData = ...;
-- Frames
local loginFrame = CreateFrame("Frame");
local questFrame = CreateFrame("Frame");
-- Events
local events = {};

-- Tables
local completedStorylines = {};

local function isActiveQuestCompleted(index)
	local questInfo = C_GossipInfo.GetActiveQuests()[index];
	
	if (questInfo.isComplete) then
		return true;
	end
	
	return false;
end

function events:GOSSIP_SHOW()
	--print("GOSSIP!");
	
	local activeQuests = C_GossipInfo.GetNumActiveQuests();
	local availableQuests = C_GossipInfo.GetNumAvailableQuests();
	
	if (activeQuests > 0) then
		-- Loop through all available quests
		for i = 1, activeQuests, 1 do
			local isCompleted = isActiveQuestCompleted(i);
			
			if (isCompleted) then
				C_GossipInfo.SelectActiveQuest(i);
			end
		end
	elseif (availableQuests > 0) then
		-- Loop through all active quests
		for i = 1, availableQuests, 1 do
			C_GossipInfo.SelectAvailableQuest(i);
		end
	end
end

function events:QUEST_GREETING()
	local activeQuests = C_GossipInfo.GetNumActiveQuests();
	local availableQuests = C_GossipInfo.GetNumAvailableQuests();
	
	--print(format("GREETING fired, available quests: %i | active quests: %i", availableQuests, activeQuests));
	
	for i = 1, activeQuests do
		C_GossipInfo.SelectActiveQuest(i);
	end
	
	for i = 1, availableQuests do
		C_GossipInfo.SelectAvailableQuest(i);
	end
end

function events:QUEST_DETAIL()
	--print("DETAILS!");
	AcceptQuest()
end

function events:QUEST_PROGRESS()
	--print("PROGRESS!");
	local isCompletable = IsQuestCompletable()
	
	if (isCompletable) then
		CompleteQuest()
	end
end

function events:QUEST_COMPLETE()
	local choices = GetNumQuestChoices();
	
	--print(format("Quest completion event raised! Amount of rewards: %i", choices));
	
	local choice = 1;
	if (choices < 2) then
		GetQuestReward(choice)
		--print("Quest completed!");
	end
	
	
	--[[
	if (choices > 1) then
		-- Find most suitable choice
	else
		GetQuestReward(choice)
	end
	]]
end

-- Login
loginFrame:RegisterEvent("PLAYER_LOGIN");
loginFrame:SetScript("OnEvent", function()
	
	if (DLUCharacterSettings.questingMode.value) then
		questFrame:SetScript("OnEvent", function(self, event, ...)
			events[event](self, ...);
		end);
		for k, v in pairs(events) do
			questFrame:RegisterEvent(k);
		end
	end
	
	loginFrame:UnregisterEvent("PLAYER_LOGIN")
end);